/*
 * SPDX-License-Identifier: CC0-1.0
 *
 * Copyright 2018-2020 Will Sargent.
 *
 * Licensed under the CC0 Public Domain Dedication;
 * You may obtain a copy of the License at
 *
 *  http://creativecommons.org/publicdomain/zero/1.0/
 */
package com.tersesystems.logback.classic;

import ch.qos.logback.classic.Level;
import ch.qos.logback.classic.spi.ILoggingEvent;
import ch.qos.logback.classic.spi.IThrowableProxy;
import ch.qos.logback.classic.spi.LoggerContextVO;
import java.util.Map;
import org.slf4j.Marker;

/**
 * Create a LoggingEvent that takes a proxy.
 *
 * <p>This looks a bit like LoggingEventVO, but does not implement serializable behavior or
 * additional logic.
 */
public class ProxyLoggingEvent implements ILoggingEvent {
  private final ILoggingEvent delegate;

  public ProxyLoggingEvent(ILoggingEvent delegate) {
    this.delegate = delegate;
  }

  public ILoggingEvent getDelegate() {
    return delegate;
  }

  @Override
  public String getThreadName() {
    return delegate.getThreadName();
  }

  @Override
  public Level getLevel() {
    return delegate.getLevel();
  }

  @Override
  public String getMessage() {
    return delegate.getMessage();
  }

  @Override
  public Object[] getArgumentArray() {
    return delegate.getArgumentArray();
  }

  @Override
  public String getFormattedMessage() {
    return delegate.getFormattedMessage();
  }

  @Override
  public String getLoggerName() {
    return delegate.getLoggerName();
  }

  @Override
  public LoggerContextVO getLoggerContextVO() {
    return delegate.getLoggerContextVO();
  }

  @Override
  public IThrowableProxy getThrowableProxy() {
    return delegate.getThrowableProxy();
  }

  @Override
  public StackTraceElement[] getCallerData() {
    return delegate.getCallerData();
  }

  @Override
  public boolean hasCallerData() {
    return delegate.hasCallerData();
  }

  @Override
  public Marker getMarker() {
    return delegate.getMarker();
  }

  @Override
  public Map<String, String> getMDCPropertyMap() {
    return delegate.getMDCPropertyMap();
  }

  @Override
  public Map<String, String> getMdc() {
    return delegate.getMdc();
  }

  @Override
  public long getTimeStamp() {
    return delegate.getTimeStamp();
  }

  @Override
  public void prepareForDeferredProcessing() {
    delegate.prepareForDeferredProcessing();
  }
}
